#
# spec file for package python-Protego
#
# Copyright (c) 2025 SUSE LLC
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via https://bugs.opensuse.org/
#


%{?sle15_python_module_pythons}
Name:           python-Protego
Version:        0.5.0
Release:        1.1
Summary:        Pure-Python robotstxt parser with support for modern conventions
License:        BSD-3-Clause
URL:            https://github.com/scrapy/protego
Source:         https://files.pythonhosted.org/packages/source/P/Protego/protego-%{version}.tar.gz
BuildRequires:  %{python_module hatchling >= 1.27.0}
BuildRequires:  %{python_module pip}
BuildRequires:  %{python_module pytest}
BuildRequires:  %{python_module setuptools}
BuildRequires:  fdupes
BuildRequires:  python-rpm-macros
BuildArch:      noarch
%python_subpackages

%description
Protego is a pure-Python `robots.txt` parser with support for modern conventions.

%prep
%setup -q -n protego-%{version}

%build
%pyproject_wheel

%install
%pyproject_install
%python_expand %fdupes %{buildroot}%{$python_sitelib}

%check
%pytest

%files %{python_files}
%doc README.rst
%license LICENSE
%{python_sitelib}/protego
%{python_sitelib}/[Pp]rotego-%{version}.dist-info

%changelog
* Thu Jul  3 2025 John Paul Adrian Glaubitz <adrian.glaubitz@suse.com>
- Update to 0.5.0
  * Restructured the code, splitting the single ``protego.py`` file
    into multiple modules. The public API remains the same but some
    internal names may now be available at different import paths.
  * Added type hints and ``py.typed``.
  * Added official support for PyPy 3.11.
  * Switched the build backend from ``setuptools`` to ``hatchling``.
  * Switched from ``setup.py`` to ``pyproject.toml``.
  * CI fixes and improvements.
- Update BuildRequires from pyproject.toml
- Update filenames of Python files matched in %%files section
- Use Python 3.11 on SLE-15 by default
* Mon Apr 14 2025 Steve Kowalik <steven.kowalik@suse.com>
- Support both lowercased and unnormalized metadata directory names.
* Tue Mar 25 2025 Steve Kowalik <steven.kowalik@suse.com>
- Lowercase metadata directory name.
* Fri Jan 24 2025 Yunus Acar <yunus.acar@suse.com>
- Update to version 0.4.0:
  * Dropped Python 3.8 support, added official Python 3.13 support.
  * Added support for //-prefixed URLs.
  * Improved the rendering of the README.rst code snippets in GitHub.
* Sat Apr 27 2024 Dirk Müller <dmueller@suse.com>
- update to 0.3.1:
  * Added official support for Python 3.12.
  * ``=`` is no longer percent-encoded in patterns, fixing many
    scenarios where patterns included query strings.
* Sun Jan  7 2024 Dirk Müller <dmueller@suse.com>
- update to 0.3.0:
  * Dropped support for Python 2.7, 3.5, 3.6, and 3.7, and
    added support for 3.11 and for the upcoming 3.12.
  * six is no longer a dependency.
  * Added support for the ``Visit-Time`` directive.
  * Fixed leading asterisks in allow and disallow values not
    being properly interpreted.
  * Protego.parse() now raises value error when *content*
    is not a string.
- drop python-Protego-no-six.patch (upstream)
* Mon Oct 17 2022 pgajdos@suse.com
- added patches
  fix https://github.com/scrapy/protego/issues/31
  + python-Protego-no-six.patch
* Fri Aug 19 2022 Yogalakshmi Arunachalam <yarunachalam@suse.com>
- - Rename README.md to README.rst in %%doc section
* Tue Aug 16 2022 Yogalakshmi Arunachalam <yarunachalam@suse.com>
- Update to 0.2.1
  * Merge pull request #21 from anubhavp28/fix_readme_content_type_and_travis_deploy_step
  * Fix content type mentioned in setup.py and Travis deploy step
- Update to 0.2.0
  Upgrade Protego version to 0.2.0
* Thu Jan 16 2020 Marketa Calabkova <mcalabkova@suse.com>
- Initial packaging (v1.0.16)
